@@ -21,3 +21,7 @@ class JulianDate(float):
         def isoformat(self):
             return str(self)
 
+        @property
+        def relative_date(self):
+            return int(self - today())
+
